@@ -62,25 +62,19 @@
 // include files for KDE
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kconfig.h>
 #include <kstandardgameaction.h>
 #include <kstandardaction.h>
 #include <kactioncollection.h>
-#include <kstandarddirs.h>
-#include <kmenubar.h>
-#include <kdebug.h>
-#include <ktextedit.h>
+#include "ksirk_debug.h"
 #include <phonon/mediaobject.h>
-#include <KPushButton>
+#include <QPushButton>
 #include <kgamepopupitem.h>
-#include <kglobal.h>
-#include <KStatusBar>
 #include <KToolBar>
-#include <KAction>
+#include <QAction>
 #include <QSvgRenderer>
-#include <KDialog>
+#include <QDialog>
 #include <KAboutData>
 
 #include <sys/utsname.h>
@@ -104,13 +98,16 @@ InvasionSlider::InvasionSlider(KGameWindow* game, GameLogic::Country * attack, G
   m_nbLArmies = new QLabel(QString::number(m_nbLArmy));
   m_nbRArmies = new QLabel(QString::number(m_nbRArmy));
 
+  QVBoxLayout* dialogLayout = new QVBoxLayout(this);
+  QDialogButtonBox* buttonBox = NULL;
+
   if (invasionType == Invasion)
   {
-    setButtons( KDialog::Ok );
+    buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
   }
   else if (invasionType == Moving)
   {
-    setButtons( KDialog::Cancel | KDialog::Ok );
+    buttonBox = new QDialogButtonBox(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
   }
 
   QWidget* widget = new QWidget(this);
@@ -171,21 +168,23 @@ InvasionSlider::InvasionSlider(KGameWindow* game, GameLogic::Country * attack, G
   //val->setText(QString::number(invadeSlide->value()));
   connect(m_invadeSlide,SIGNAL(valueChanged(int)),this,SLOT(slideMove(int)));
   connect(m_invadeSlide,SIGNAL(sliderReleased()),this,SLOT(slideReleased()));
-  connect(this,SIGNAL(okClicked()),this,SLOT(slideClose()));
+  connect(buttonBox,SIGNAL(accepted()),this,SLOT(slideClose()));
   if (invasionType == Moving)
   {
-    connect(this,SIGNAL(cancelClicked()),this,SLOT(slideCancel()));
+    connect(buttonBox,SIGNAL(rejected()),this,SLOT(slideCancel()));
   }
 
-  setMainWidget(widget);
-  
   widget->setLayout(wSlideLayout);
+
+  dialogLayout->addWidget(widget);
+  if (buttonBox)
+      dialogLayout->addWidget(buttonBox);
   setWindowModality(Qt::ApplicationModal);
 }
 
 void InvasionSlider::slideMove(int v)
 {
-  kDebug() << v;
+  qCDebug(KSIRK_LOG) << v;
   m_nbLArmy = m_nbLArmy-(v-m_currentSlideValue);
   m_nbRArmy = m_nbRArmy+(v-m_currentSlideValue);
   m_nbLArmies->setText(QString::number(m_nbLArmy));
@@ -198,12 +197,12 @@ void InvasionSlider::slideMove(int v)
 
 void InvasionSlider::slideReleased()
 {
-  kDebug() << "do nothing";
+  qCDebug(KSIRK_LOG) << "do nothing";
 }
 
 void InvasionSlider::slideClose()
 {
-  kDebug() << m_currentSlideValue;
+  qCDebug(KSIRK_LOG) << m_currentSlideValue;
   
   QByteArray buffer;
   QDataStream stream(&buffer, QIODevice::WriteOnly);
@@ -215,13 +214,15 @@ void InvasionSlider::slideClose()
   m_game->automaton()->currentPlayerPlayed(true);
   QPointF point;
   m_game->automaton()->gameEvent("actionNextPlayer", point);
+  accept();
 }
 
 void InvasionSlider::slideCancel()
 {
-  kDebug() << "Move cancel";
+  qCDebug(KSIRK_LOG) << "Move cancel";
+  reject();
 }
 
 } // closing namespace Ksirk
 
-#include "InvasionSlider.moc"
+
