@@ -21,8 +21,8 @@
 #include "kgamewin.h"
 #include "gameautomaton.h"
 
-#include <kdebug.h>
-#include <klocale.h>
+#include "ksirk_debug.h"
+#include <KLocalizedString>
 #include <kmessagebox.h>
 
 namespace Ksirk {
@@ -56,21 +56,21 @@ m_player(0)
 Goal::Goal(const Goal& goal)
 {
   m_automaton = goal.m_automaton;
-  kDebug() << "Goal copy constructor :" << endl;
+  qCDebug(KSIRK_LOG) << "Goal copy constructor :" << endl;
   m_type = goal.m_type;
-  kDebug() << "  type="<< m_type << endl;
+  qCDebug(KSIRK_LOG) << "  type="<< m_type << endl;
   m_description = goal.m_description;
-  kDebug() << "  description="<< m_description << endl;
+  qCDebug(KSIRK_LOG) << "  description="<< m_description << endl;
   m_nbCountries = goal.m_nbCountries;
-  kDebug() << "  nbCountries="<< m_nbCountries << endl;
+  qCDebug(KSIRK_LOG) << "  nbCountries="<< m_nbCountries << endl;
   m_nbArmiesByCountry = goal.m_nbArmiesByCountry;
-  kDebug() << "  nbArmiesByCountry="<< m_nbArmiesByCountry << endl;
+  qCDebug(KSIRK_LOG) << "  nbArmiesByCountry="<< m_nbArmiesByCountry << endl;
   m_continents = goal.m_continents;
-  kDebug() << "  continents: "<< m_continents.size() << endl;
+  qCDebug(KSIRK_LOG) << "  continents: "<< m_continents.size() << endl;
   m_players = goal.m_players;
-  kDebug() << "  players: "<< m_players.size() << endl;
+  qCDebug(KSIRK_LOG) << "  players: "<< m_players.size() << endl;
   m_player = goal.m_player;
-  kDebug() << "  player: "<< m_player << endl;
+  qCDebug(KSIRK_LOG) << "  player: "<< m_player << endl;
 }
 
 Goal::~Goal()
@@ -79,7 +79,7 @@ Goal::~Goal()
 
 bool Goal::checkFor(const GameLogic::Player* player) const 
 {
-  kDebug() << message(GoalAdvance);
+  qCDebug(KSIRK_LOG) << message(GoalAdvance);
   int diff = 0;
   switch (type())
   {
@@ -115,7 +115,7 @@ bool Goal::checkFor(const GameLogic::Player* player) const
 
 bool Goal::checkCountriesFor(const GameLogic::Player* player) const
 {
-  kDebug() << player->name();
+  qCDebug(KSIRK_LOG) << player->name();
   if (player->getNbCountries() >= m_nbCountries)
   {
     uint nbCountriesOk = 0;
@@ -136,10 +136,10 @@ bool Goal::checkCountriesFor(const GameLogic::Player* player) const
 
 bool Goal::checkContinentsFor(const GameLogic::Player* player) const
 {
-  kDebug() << "Goal::checkContinentsFor " << player->name() << endl;
+  qCDebug(KSIRK_LOG) << "Goal::checkContinentsFor " << player->name() << endl;
   foreach (const QString& continent, m_continents)
   {
-    kDebug() << "Should be owned continent id: " << continent<< endl;
+    qCDebug(KSIRK_LOG) << "Should be owned continent id: " << continent<< endl;
     if ( m_automaton->game()->theWorld()->continentNamed(continent) == 0
        || m_automaton->game()->theWorld()->continentNamed(continent)->owner() != player)
     {
@@ -166,7 +166,7 @@ bool Goal::checkContinentsFor(const GameLogic::Player* player) const
 
 QString Goal::message(int displayType) const
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   KLocalizedString res;
 
   QList<QString>::const_iterator it, it_end, it_next;
@@ -188,7 +188,7 @@ QString Goal::message(int displayType) const
       {
         res = res.subs(m_player->name());
       }
-      kDebug() << "Goal type='" << m_type << "' mes = '" << res.toString() << "'" << endl;
+      qCDebug(KSIRK_LOG) << "Goal type='" << m_type << "' mes = '" << res.toString() << "'" << endl;
     
       QList<unsigned int>::const_iterator it, it_end;
       switch (m_type)
@@ -196,15 +196,15 @@ QString Goal::message(int displayType) const
       case Goal::GoalPlayer :
         if (!m_players.empty())
         {
-          kDebug() << "  player name='" << *m_players.begin() << endl;
-          kDebug() << "  this is player='" << m_automaton->playerNamed(*m_players.begin()) << endl;
+          qCDebug(KSIRK_LOG) << "  player name='" << *m_players.begin() << endl;
+          qCDebug(KSIRK_LOG) << "  this is player='" << m_automaton->playerNamed(*m_players.begin()) << endl;
           if (m_automaton->playerNamed(*m_players.begin())==0)
           {
             res = res.subs(i18n("%1 (already dead)",*m_players.begin()));
           }
           else
           {
-            kDebug() << "  its name is='" << *m_players.begin() << endl;
+            qCDebug(KSIRK_LOG) << "  its name is='" << *m_players.begin() << endl;
             res = res.subs(*m_players.begin());
           }
           res = res.subs(m_nbCountries);
@@ -215,11 +215,11 @@ QString Goal::message(int displayType) const
         }
         break;
       case Goal::Countries:
-        kDebug() << "  arg1 = '" << m_nbCountries << "'" << endl;
+        qCDebug(KSIRK_LOG) << "  arg1 = '" << m_nbCountries << "'" << endl;
         res=res.subs(m_nbCountries);
         if (m_nbArmiesByCountry > 0)
         {
-          kDebug() << "  arg2 = '" << m_nbArmiesByCountry << "'" << endl;
+          qCDebug(KSIRK_LOG) << "  arg2 = '" << m_nbArmiesByCountry << "'" << endl;
           res=res.subs(m_nbArmiesByCountry);
         }
         break;
@@ -228,7 +228,7 @@ QString Goal::message(int displayType) const
         {
           if (continent != QString())
           {
-            kDebug() << "  arg = '" << continent << "'" << endl;
+            qCDebug(KSIRK_LOG) << "  arg = '" << continent << "'" << endl;
             res=res.subs(i18n(continent.toUtf8().data()));
           }
         }
@@ -328,7 +328,7 @@ QString Goal::message(int displayType) const
   
 void Goal::show(int displayType)
 {
-  kDebug() << message(displayType);
+  qCDebug(KSIRK_LOG) << message(displayType);
 //   m_automaton->game()->showMessage(message(displayType),5, KGameWindow::ForceShowing);
   KMessageBox::information(
                             m_automaton->game(),
@@ -338,49 +338,49 @@ void Goal::show(int displayType)
 
 QDataStream& operator<<(QDataStream& stream, const Goal& goal)
 {
-  kDebug() << "Goal operator<< : type" << goal.type()<< endl;
+  qCDebug(KSIRK_LOG) << "Goal operator<< : type" << goal.type()<< endl;
   stream << quint32(goal.type());
   if (goal.player() != 0)
   {
-    kDebug() << "Goal operator<< : player " << goal.player()->id() << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator<< : player " << goal.player()->id() << endl;
     stream << quint32(goal.player()->id());
   }
   else
   {
-    kDebug() << "Goal operator<< : player " << 0 << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator<< : player " << 0 << endl;
     stream << quint32(0);
   }
-  kDebug() << "Goal operator<< : description " << goal.description() << endl;
+  qCDebug(KSIRK_LOG) << "Goal operator<< : description " << goal.description() << endl;
   stream << goal.description();
   QList<QString>::ConstIterator it, it_end;
   QList<QString>::ConstIterator itc, itc_end;
   switch (goal.type())
   {
   case Goal::GoalPlayer :
-    kDebug() << "Goal operator<< : players " << goal.players().size() << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator<< : players " << goal.players().size() << endl;
     stream << quint32(goal.players().size());
     it = goal.players().constBegin(); it_end = goal.players().constEnd();
     for (; it != it_end; it++)
     {
-      kDebug() << "Goal operator<< : player " << (*it) << endl;
+      qCDebug(KSIRK_LOG) << "Goal operator<< : player " << (*it) << endl;
       stream << *it;
     }
-    kDebug() << "Goal operator<< : nbCountries " << goal.nbCountries() << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator<< : nbCountries " << goal.nbCountries() << endl;
     stream << quint32(goal.nbCountries());
     break;
   case Goal::Countries:
-    kDebug() << "Goal operator<< : nbCountries " << goal.nbCountries() << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator<< : nbCountries " << goal.nbCountries() << endl;
     stream << quint32(goal.nbCountries());
-    kDebug() << "Goal operator<< : nbArmiesByCountry " << goal.nbArmiesByCountry() << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator<< : nbArmiesByCountry " << goal.nbArmiesByCountry() << endl;
     stream << quint32(goal.nbArmiesByCountry());
     break;
   case Goal::Continents:
-    kDebug() << "Goal operator<< : continents " << goal.continents().size() << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator<< : continents " << goal.continents().size() << endl;
     stream << quint32(goal.continents().size());
     itc = goal.continents().constBegin(); itc_end = goal.continents().constEnd();
     for (; itc != itc_end; itc++)
     {
-      kDebug() << "Goal operator<< : continent " << (*itc) << endl;
+      qCDebug(KSIRK_LOG) << "Goal operator<< : continent " << (*itc) << endl;
       stream << (*itc);
     }
     break;
@@ -391,7 +391,7 @@ QDataStream& operator<<(QDataStream& stream, const Goal& goal)
 
 QDataStream& operator>>(QDataStream& stream, Goal& goal)
 {
-  kDebug() << "Goal operator>>" << endl;
+  qCDebug(KSIRK_LOG) << "Goal operator>>" << endl;
   quint32 type;
   QString description;
   QString playerName;
@@ -399,46 +399,46 @@ QDataStream& operator>>(QDataStream& stream, Goal& goal)
   QString id;
   quint32 ownerId;
   stream >> type;
-  kDebug() << "Goal operator>> type: " << type << endl;
+  qCDebug(KSIRK_LOG) << "Goal operator>> type: " << type << endl;
   stream >> ownerId;
-  kDebug() << "Goal operator>> ownerId: " << ownerId << endl;
+  qCDebug(KSIRK_LOG) << "Goal operator>> ownerId: " << ownerId << endl;
   goal.player(static_cast<Player*>(goal.m_automaton->findPlayer(ownerId)));
   goal.type(Goal::GoalType(type));
   stream >> description;
-  kDebug() << "Goal operator>> description: " << description << endl;
+  qCDebug(KSIRK_LOG) << "Goal operator>> description: " << description << endl;
   goal.description(description);
   switch (type)
   {
   case Goal::GoalPlayer :
     goal.players().clear();
     stream >> nbp;
-    kDebug() << "Goal operator>> nbp: " << nbp << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator>> nbp: " << nbp << endl;
     for (quint32 i = 0; i < nbp; i++)
     {
       stream >> playerName;
-      kDebug() << "Goal operator>> player name: " << playerName << endl;
+      qCDebug(KSIRK_LOG) << "Goal operator>> player name: " << playerName << endl;
       goal.players().push_back(playerName);
     }
     stream >> nb;
-    kDebug() << "Goal operator>> nbCountries: " << nb << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator>> nbCountries: " << nb << endl;
     goal.nbCountries(nb);
     break;
   case Goal::Countries:
     stream >> nb;
-    kDebug() << "Goal operator>> nbCountries: " << nb << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator>> nbCountries: " << nb << endl;
     goal.nbCountries(nb);
     stream >> nb;
     goal.nbArmiesByCountry(nb);
-    kDebug() << "Goal operator>> nbArmiesByCountry: " << nb << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator>> nbArmiesByCountry: " << nb << endl;
     break;
   case Goal::Continents:
     stream >> nb;
-    kDebug() << "Goal operator>> nbContinents: " << nb << endl;
+    qCDebug(KSIRK_LOG) << "Goal operator>> nbContinents: " << nb << endl;
     goal.continents().clear();
     for (quint32 i = 0; i < nb; i++)
     {
       stream >> id;
-      kDebug() << "Goal operator>> continent: " << id << endl;
+      qCDebug(KSIRK_LOG) << "Goal operator>> continent: " << id << endl;
       goal.continents().push_back(id);
     }
     break;
