@@ -40,16 +40,14 @@
 
 #include <kcomponentdata.h>
 #include <kconfig.h>
-#include <kdebug.h>
 #include <kmessagebox.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kaboutdata.h>
 #include <k3socketbase.h>
 #include <kpassworddialog.h>
 #include <kinputdialog.h>
 #include <kicon.h>
 #include <kactionmenu.h>
-#include <kglobal.h>
 #include <KComponentData>
 
 #include "jabberconnector.h"
@@ -87,7 +85,7 @@
 JabberAccount::JabberAccount (JabberProtocol * parent, const QString & accountId)
 			  :JabberProtocol( parent/*, accountId, false */)
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Instantiating new account " << accountId;
+	qCDebug(JABBER_PROTOCOL_LOG) << "Instantiating new account " << accountId;
 
 	m_protocol = parent;
 
@@ -233,7 +231,7 @@ return false;
 
 void JabberAccount::connectWithPassword ( const QString &password )
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "called";
+	qCDebug(JABBER_PROTOCOL_LOG) << "called";
 
 	/* Cancel connection process if no password has been supplied. */
 	if ( password.isEmpty () )
@@ -304,7 +302,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 	m_jabberClient->setAllowPlainTextPassword ( false );
 
 	// enable file transfer (if empty, IP will be set after connection has been established)
-// 	KConfigGroup config = KGlobal::config()->group ( "Jabber" );
+// 	KConfigGroup config = KSharedConfig::openConfig()->group ( "Jabber" );
 // 	m_jabberClient->setFileTransfersEnabled ( true, config.readEntry ( "LocalIP" ) );
 // 	setS5BServerPort ( config.readEntry ( "LocalPort", 8010 ) );
 
@@ -362,11 +360,11 @@ void JabberAccount::connectWithPassword ( const QString &password )
 		timezoneString = str;
 	//END of timezone code
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Determined timezone " << timezoneString << " with UTC offset " << timezoneOffset << " hours.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Determined timezone " << timezoneString << " with UTC offset " << timezoneOffset << " hours.";
 
 	m_jabberClient->setTimeZone ( timezoneString, timezoneOffset );
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Connecting to Jabber server " << server() << ":" << port();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Connecting to Jabber server " << server() << ":" << port();
 
 	setPresence( XMPP::Status ("connecting", "", 0, true) );
 
@@ -391,7 +389,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 void JabberAccount::slotClientDebugMessage ( const QString &msg )
 {
 
-	kDebug (JABBER_DEBUG_PROTOCOL) << msg;
+	qCDebug(JABBER_PROTOCOL_LOG) << msg;
 
 }
 
@@ -507,7 +505,7 @@ void JabberAccount::slotHandleTLSWarning (
 		QCA::TLS::IdentityResult identityResult,
 		QCA::Validity validityResult )
 {
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Handling TLS warning...";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Handling TLS warning...";
 
 	if ( handleTLSWarning ( m_jabberClient, identityResult, validityResult ) )
 	{
@@ -524,7 +522,7 @@ void JabberAccount::slotHandleTLSWarning (
 
 void JabberAccount::slotClientError ( JabberClient::ErrorCode errorCode )
 {
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Handling client error...";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Handling client error...";
 
 	switch ( errorCode )
 	{
@@ -541,12 +539,12 @@ void JabberAccount::slotClientError ( JabberClient::ErrorCode errorCode )
 
 void JabberAccount::slotConnected ()
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Connected to Jabber server.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Connected to Jabber server.";
 	
 #ifdef SUPPORT_JINGLE
 	if(!m_voiceCaller)
 	{
-		kDebug(JABBER_DEBUG_GLOBAL) << "Creating Jingle Voice caller...";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Creating Jingle Voice caller...";
 		m_voiceCaller = new JingleVoiceCaller( this );
 		QObject::connect(m_voiceCaller,SIGNAL(incoming(Jid)),this,SLOT(slotIncomingVoiceCall(Jid)));
 		m_voiceCaller->initialize();
@@ -555,7 +553,7 @@ void JabberAccount::slotConnected ()
 #if 0
 	if(!m_jingleSessionManager)
 	{
-		kDebug(JABBER_DEBUG_GLOBAL) << "Creating Jingle Session Manager...";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Creating Jingle Session Manager...";
 		m_jingleSessionManager = new JingleSessionManager( this );
 		QObject::connect(m_jingleSessionManager, SIGNAL(incomingSession(QString,JingleSession*)), this, SLOT(slotIncomingJingleSession(QString,JingleSession*)));
 	}
@@ -565,7 +563,7 @@ void JabberAccount::slotConnected ()
 	m_jabberClient->client()->addExtension("voice-v1", Features(QString("http://www.google.com/xmpp/protocol/voice/v1")));
 #endif
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Requesting roster...";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Requesting roster...";
 	m_jabberClient->requestRoster ();
 }
 
@@ -584,7 +582,7 @@ void JabberAccount::slotRosterRequestFinished ( bool success )
 	* information before we have updated our roster with actual
 	* contacts from the server! (Iris won't forward presence
 	* information in that case either). */
-	kDebug (JABBER_DEBUG_GLOBAL) << "Setting initial presence...";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Setting initial presence...";
 	setPresence ( m_initialPresence );
 
 }
@@ -604,7 +602,7 @@ void JabberAccount::setOnlineStatus( const JabberProtocol::OnlineStatus& status,
   if( status == JabberProtocol::JabberOffline )
 	{
 			xmppStatus.setIsAvailable( false );
-			kDebug (JABBER_DEBUG_GLOBAL) << "CROSS YOUR FINGERS! THIS IS GONNA BE WILD";
+			qCDebug(JABBER_PROTOCOL_LOG) << "CROSS YOUR FINGERS! THIS IS GONNA BE WILD";
             disconnect (0/*Manual*/, xmppStatus);
             return;
     }
@@ -634,11 +632,11 @@ void JabberAccount::setStatusMessage( const QString& statusMessage )
 
 void JabberAccount::disconnect ( int reason )
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "disconnect() called";
+	qCDebug(JABBER_PROTOCOL_LOG) << "disconnect() called";
 
 	if (isConnected ())
 	{
-		kDebug (JABBER_DEBUG_GLOBAL) << "Still connected, closing connection...";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Still connected, closing connection...";
 		/* Tell backend class to disconnect. */
 		m_jabberClient->disconnect ();
 	}
@@ -656,18 +654,18 @@ void JabberAccount::disconnect ( int reason )
 	 * Instead, the instance will lurk until the next
 	 * connection attempt.
 	 */
-	kDebug (JABBER_DEBUG_GLOBAL) << "Disconnected.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Disconnected.";
 
 // 	disconnected ( reason );
 }
 
 void JabberAccount::disconnect( int reason, XMPP::Status &status )
 {
-    kDebug (JABBER_DEBUG_GLOBAL) << "disconnect( reason, status ) called";
+    qCDebug(JABBER_PROTOCOL_LOG) << "disconnect( reason, status ) called";
     
 	if (isConnected ())
 	{
-		kDebug (JABBER_DEBUG_GLOBAL) << "Still connected, closing connection...";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Still connected, closing connection...";
 		/* Tell backend class to disconnect. */
 		m_jabberClient->disconnect (status);
 	}
@@ -684,7 +682,7 @@ void JabberAccount::disconnect( int reason, XMPP::Status &status )
 	 * Instead, the instance will lurk until the next
 	 * connection attempt.
 	 */
-	kDebug (JABBER_DEBUG_GLOBAL) << "Disconnected.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Disconnected.";
 
 // 	Kopete::Account::disconnected ( reason );
 }
@@ -706,7 +704,7 @@ void JabberAccount::slotDisconnect ()
 
 void JabberAccount::slotCSDisconnected ()
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Disconnected from Jabber server.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Disconnected from Jabber server.";
 
 	/*
 	 * We should delete the JabberClient instance here,
@@ -990,19 +988,19 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 
 void JabberAccount::slotCSError ( int error )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Error in stream signalled.";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Error in stream signalled.";
 
 	if ( ( error == XMPP::ClientStream::ErrAuth )
 		&& ( client()->clientStream()->errorCondition () == XMPP::ClientStream::NotAuthorized ) )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Incorrect password, retrying.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Incorrect password, retrying.";
 		disconnect(/*Kopete::Account::BadPassword*/0);
 	}
 	else
 	{
 		int errorClass =  0;
 
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "Disconnecting.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Disconnecting.";
 
 		// display message to user
 		if(!m_removing) //when removing the account, connection errors are normal.
@@ -1019,7 +1017,7 @@ void JabberAccount::slotCSError ( int error )
 /* Set presence (usually called by dialog widget). */
 void JabberAccount::setPresence ( const XMPP::Status &status )
 {
-	kDebug(JABBER_DEBUG_GLOBAL) << "Status: " << status.show () << ", Reason: " << status.status ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Status: " << status.show () << ", Reason: " << status.status ();
 
 	// fetch input status
 	XMPP::Status newStatus = status;
@@ -1055,7 +1053,7 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 		 */
 		if (isConnected())
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "Sending new presence to the server.";
+			qCDebug(JABBER_PROTOCOL_LOG) << "Sending new presence to the server.";
 
 			XMPP::JT_Presence * task = new XMPP::JT_Presence ( client()->rootTask ());
 
@@ -1064,7 +1062,7 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 		}
 		else
 		{
-			kDebug(JABBER_DEBUG_GLOBAL) << "We were not connected, presence update aborted.";
+			qCDebug(JABBER_PROTOCOL_LOG) << "We were not connected, presence update aborted.";
 		}
 	}
 
@@ -1089,14 +1087,14 @@ void JabberAccount::slotXMPPConsole ()
 
 void JabberAccount::slotSubscription (const XMPP::Jid & jid, const QString & type)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << jid.full () << ", " << type;
+	qCDebug(JABBER_PROTOCOL_LOG) << jid.full () << ", " << type;
 
 	if (type == "subscribe")
 	{
 		/*
 		 * A user wants to subscribe to our presence.
 		 */
-		kDebug (JABBER_DEBUG_GLOBAL) << jid.full () << " is asking for authorization to subscribe.";
+		qCDebug(JABBER_PROTOCOL_LOG) << jid.full () << " is asking for authorization to subscribe.";
 
 		// Is the user already in our contact list?
 // 		JabberBaseContact *contact = contactPool()->findExactMatch( jid );
@@ -1122,7 +1120,7 @@ void JabberAccount::slotSubscription (const XMPP::Jid & jid, const QString & typ
 		/*
 		 * Someone else removed our authorization to see them.
 		 */
-		kDebug (JABBER_DEBUG_GLOBAL) << jid.full() << " revoked our presence authorization";
+		qCDebug(JABBER_PROTOCOL_LOG) << jid.full() << " revoked our presence authorization";
 
 		XMPP::JT_Roster *task;
 
@@ -1237,7 +1235,7 @@ void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 	 * a roster item here.
 	 */
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "New roster item " << item.jid().full () << " (Subscription: " << item.subscription().toString () << ")";
+	qCDebug(JABBER_PROTOCOL_LOG) << "New roster item " << item.jid().full () << " (Subscription: " << item.subscription().toString () << ")";
 
 	/*
 	 * See if the contact need to be added, according to the criterias of 
@@ -1314,7 +1312,7 @@ void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 /*		Kopete::MetaContact *metaContact=c->metaContact();
 		if(metaContact->isTemporary())
 			return;
-		kDebug (JABBER_DEBUG_GLOBAL) << c->contactId() << 
+		qCDebug(JABBER_PROTOCOL_LOG) << c->contactId() << 
 				" is on the contact list while it shouldn't.  we are removing it.  - " << c << endl;
 		delete c;
 		if(metaContact->contacts().isEmpty())
@@ -1325,7 +1323,7 @@ void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 
 void JabberAccount::slotContactDeleted (const XMPP::RosterItem & item)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Deleting contact " << item.jid().full ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Deleting contact " << item.jid().full ();
 
 	// since the contact instance will get deleted here, the GUI should be updated
 	contactPool()->removeContact ( item.jid () );
@@ -1334,7 +1332,7 @@ void JabberAccount::slotContactDeleted (const XMPP::RosterItem & item)
 
 void JabberAccount::slotReceivedMessage (const XMPP::Message & message)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "New message from " << message.from().full ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "New message from " << message.from().full ();
 
 	JabberBaseContact *contactFrom;
 
@@ -1355,7 +1353,7 @@ void JabberAccount::slotReceivedMessage (const XMPP::Message & message)
 		 */
 		if ( !contactFrom )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "WARNING: Received a groupchat message but couldn't find room contact. Ignoring message.";
+			qCDebug(JABBER_PROTOCOL_LOG) << "WARNING: Received a groupchat message but couldn't find room contact. Ignoring message.";
 			return;
 		}
 	}
@@ -1382,7 +1380,7 @@ void JabberAccount::slotReceivedMessage (const XMPP::Message & message)
 			XMPP::Jid jid ( message.from().userHost () );
 
 			// the contact is not in our pool, add it as a temporary contact
-			kDebug (JABBER_DEBUG_GLOBAL) << jid.full () << " is unknown to us, creating temporary contact.";
+			qCDebug(JABBER_PROTOCOL_LOG) << jid.full () << " is unknown to us, creating temporary contact.";
 
 // 			Kopete::MetaContact *metaContact = new Kopete::MetaContact ();
 // 
@@ -1415,7 +1413,7 @@ void JabberAccount::slotJoinNewChat ()
 
 void JabberAccount::slotGroupChatJoined (const XMPP::Jid & jid)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Joined groupchat " << jid.full ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Joined groupchat " << jid.full ();
 
 	// Create new meta contact that holds the groupchat contact.
 // 	Kopete::MetaContact *metaContact = new Kopete::MetaContact ();
@@ -1452,7 +1450,7 @@ void JabberAccount::slotGroupChatJoined (const XMPP::Jid & jid)
 
 void JabberAccount::slotGroupChatLeft (const XMPP::Jid & jid)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Left groupchat " << jid.full ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Left groupchat " << jid.full ();
 	
 	// remove group contact from list
 // 	Kopete::Contact *contact = 
@@ -1474,20 +1472,20 @@ void JabberAccount::slotGroupChatLeft (const XMPP::Jid & jid)
 
 void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::Status & status)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Received groupchat presence for room " << jid.full ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Received groupchat presence for room " << jid.full ();
 
 	// fetch room contact (the one without resource)
 	JabberGroupContact *groupContact = dynamic_cast<JabberGroupContact *>( contactPool()->findExactMatch ( XMPP::Jid ( jid.userHost () ) ) );
 
 	if ( !groupContact )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << "WARNING: Groupchat presence signalled, but we don't have a room contact?";
+		qCDebug(JABBER_PROTOCOL_LOG) << "WARNING: Groupchat presence signalled, but we don't have a room contact?";
 		return;
 	}
 
 	if ( !status.isAvailable () )
 	{
-		kDebug ( JABBER_DEBUG_GLOBAL ) << jid.full () << " has become unavailable, removing from room";
+		qCDebug(JABBER_PROTOCOL_LOG) << jid.full () << " has become unavailable, removing from room";
 
 		// remove the resource from the pool
 		resourcePool()->removeResource ( jid, XMPP::Resource ( jid.resource (), status ) );
@@ -1508,7 +1506,7 @@ void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::St
 
 void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const QString &reason)
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Group chat error - room " << jid.full () << " had error " << error << " (" << reason << ")";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Group chat error - room " << jid.full () << " had error " << error << " (" << reason << ")";
 
 	switch (error)
 	{
@@ -1564,7 +1562,7 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const Q
 void JabberAccount::slotResourceAvailable (const XMPP::Jid & jid, const XMPP::Resource & resource)
 {
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "New resource available for " << jid.full();
+	qCDebug(JABBER_PROTOCOL_LOG) << "New resource available for " << jid.full();
 
 	resourcePool()->addResource ( jid, resource );
 
@@ -1573,7 +1571,7 @@ void JabberAccount::slotResourceAvailable (const XMPP::Jid & jid, const XMPP::Re
 void JabberAccount::slotResourceUnavailable (const XMPP::Jid & jid, const XMPP::Resource & resource)
 {
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "Resource now unavailable for " << jid.full ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Resource now unavailable for " << jid.full ();
 
 	resourcePool()->removeResource ( jid, resource );
 
@@ -1615,11 +1613,11 @@ void JabberAccount::slotGetServices ()
 
 // void JabberAccount::slotIncomingVoiceCall( const Jid &jid )
 // {
-// 	kDebug(JABBER_DEBUG_GLOBAL) ;
+// 	qCDebug(JABBER_PROTOCOL_LOG) ;
 // #ifdef SUPPORT_JINGLE
 // 	if(voiceCaller())
 // 	{
-// 		kDebug(JABBER_DEBUG_GLOBAL) << "Showing voice dialog.";
+// 		qCDebug(JABBER_PROTOCOL_LOG) << "Showing voice dialog.";
 // 		JingleVoiceSessionDialog *voiceDialog = new JingleVoiceSessionDialog( jid, voiceCaller() );
 // 		voiceDialog->show();
 // 	}
@@ -1718,6 +1716,6 @@ void JabberAccount::slotUnregisterFinished( )
 // 		Kopete::AccountManager::self()->removeAccount( this ); //this will delete this
 }
 
-#include "jabberaccount.moc"
+
 
 // vim: set noet ts=4 sts=4 sw=4:
