@@ -16,8 +16,7 @@
   * *************************************************************************
   */
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
 #include <qtimer.h>
@@ -91,7 +90,7 @@ bool JabberBaseContact::isReachable ()
 
 void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 {
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Synchronizing local copy of " << contactId() << " with information received from server.  (name='" << item.name() << "' groups='" << item.groups() << "')";
+	qCDebug(JABBER_PROTOCOL_LOG) << "Synchronizing local copy of " << contactId() << " with information received from server.  (name='" << item.name() << "' groups='" << item.groups() << "')";
 
 	mRosterItem = item;
 
@@ -114,7 +113,7 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 		if ( !item.name().isEmpty () && item.name() != item.jid().bare() 
 			&& metaContact()->customDisplayName() != item.name () )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "setting display name of " << contactId () << " to " << item.name();
+			qCDebug(JABBER_PROTOCOL_LOG) << "setting display name of " << contactId () << " to " << item.name();
 			metaContact()->setDisplayName ( item.name () );
 		}
 	}
@@ -196,13 +195,13 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 	
 		foreach ( Kopete::Group *group, groupsToRemoveFrom )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Removing " << contactId() << " from group " << group->displayName ();
+			qCDebug(JABBER_PROTOCOL_LOG) << "Removing " << contactId() << " from group " << group->displayName ();
 			metaContact()->removeFromGroup ( group );
 		}
 	
 		foreach ( Kopete::Group *group, groupsToAddTo )
 		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "Adding " << contactId() << " to group " << group->displayName ();
+			qCDebug(JABBER_PROTOCOL_LOG) << "Adding " << contactId() << " to group " << group->displayName ();
 			metaContact()->addToGroup ( group );
 		}
 	}
@@ -273,7 +272,7 @@ void JabberBaseContact::updateResourceList ()
 		
 		// resource timestamp
 		resourceListStr += QString ( "<tr><td>%1: %2</td></tr>" ).
-						   arg ( i18n ( "Timestamp" ), KGlobal::locale()->formatDateTime ( (*it)->resource().status().timeStamp(), KLocale::ShortDate, true ) );
+						   arg ( i18n ( "Timestamp" ), KLocale::global()->formatDateTime ( (*it)->resource().status().timeStamp(), KLocale::ShortDate, true ) );
 
 		// message, if any
 		if ( !(*it)->resource().status().status().trimmed().isEmpty () )
@@ -293,7 +292,7 @@ void JabberBaseContact::updateResourceList ()
 
 void JabberBaseContact::reevaluateStatus ()
 {
-	kDebug (JABBER_DEBUG_GLOBAL) << "Determining new status for " << contactId ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Determining new status for " << contactId ();
 
 	Kopete::OnlineStatus status;
 	XMPP::Resource resource = account()->resourcePool()->bestResource ( mRosterItem.jid () );
@@ -316,7 +315,7 @@ void JabberBaseContact::reevaluateStatus ()
 
 	updateResourceList ();
 
-	kDebug (JABBER_DEBUG_GLOBAL) << "New status for " << contactId () << " is " << status.description ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "New status for " << contactId () << " is " << status.description ();
 	setOnlineStatus ( status );
 
 	/*
@@ -398,7 +397,7 @@ void JabberBaseContact::slotUserInfo( )
 
 void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 {
-	kDebug ( JABBER_DEBUG_GLOBAL ) << "Updating vCard for " << contactId ();
+	qCDebug(JABBER_PROTOCOL_LOG) << "Updating vCard for " << contactId ();
 
 	// update vCard cache timestamp if this is not a temporary contact
 	if ( metaContact() && !metaContact()->isTemporary () )
@@ -626,7 +625,7 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	// photo() is a QByteArray
 	if ( !vCard.photo().isEmpty() )
 	{
-		kDebug( JABBER_DEBUG_GLOBAL ) << "Contact has a photo embedded into his vCard.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Contact has a photo embedded into his vCard.";
 
 		// QImage is used to save to disk in PNG later.
 		contactPhoto = QImage::fromData( vCard.photo() );
@@ -644,7 +643,7 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 		}
 
 
-		kDebug( JABBER_DEBUG_GLOBAL ) << "Contact photo is a URI.";
+		qCDebug(JABBER_PROTOCOL_LOG) << "Contact photo is a URI.";
 
 		contactPhoto = QImage( tempPhotoPath );
 		
@@ -662,7 +661,7 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	// Save the image to the disk, then set the property.
 	if(!entry.path.isNull())
 	{
-		kDebug( JABBER_DEBUG_GLOBAL ) << "Setting photo for contact: " << contactId();
+		qCDebug(JABBER_PROTOCOL_LOG) << "Setting photo for contact: " << contactId();
 		setProperty( protocol()->propPhoto, entry.path );
 	}
 
@@ -671,6 +670,6 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 
 
 
-#include "jabberbasecontact.moc"
+
 
 // vim: set noet ts=4 sts=4 sw=4:
